! Compile this with:
! gfortran -I$AMBERHOME/include -L$AMBERHOME/lib -o qmmm_sander qmmm_sander.F90 -lsander

program qmmm_sander

use sander_api, only: sander_input, pme_sander_input, &
     sander_setup, energy_forces, &
     sander_cleanup, potential_energy_rec, &
     get_inpcrd_natom, read_inpcrd_file, &
     sander_natom, qmmm_input_options, &
     qm_sander_input

implicit none
double precision, allocatable, dimension(:) :: crd, frc
double precision, dimension(6) :: box
type(sander_input) :: inp
type(qmmm_input_options) :: qm_inp
type(potential_energy_rec) :: ene
integer :: natom, ierr

! Find how many atoms are in our inpcrd file
call get_inpcrd_natom("frame.rst7", natom)
allocate(crd(natom*3), stat=ierr)

! Parse the inpcrd file
call read_inpcrd_file("frame.rst7", crd, box, ierr)

! Set up input options to use PME
call pme_sander_input(inp)
inp%ifqnt = 1

call qm_sander_input(qm_inp)
     qm_inp%qmmask = "@83-97"
     qm_inp%qmcut = 9.d0

! Set up our system
call sander_setup("state00.parm7", crd, box, inp, qm_inp, ierr)

! Coordinate array is no longer needed
deallocate(crd)

! Find out how big our force array must be
call sander_natom(natom)
allocate(frc(natom*3), stat=ierr)

call energy_forces(ene, frc)

!write(*,*) ene

call sander_cleanup
deallocate(frc)
return

end program qmmm_sander
